@@ -1,4 +1,4 @@
-from categories.tests import views
+from categories.tests.category_import import *
 from categories.tests.templatetags import *
 
 __fixtures__ = ['categories.json']
